@@ -212,9 +212,12 @@ typedef enum {
   DT_H5D_mpio_actual_io_mode_t,
   DT_H5D_mpio_no_collective_cause_t,
   DT_H5D_space_status_t,
+  DT_H5D_vds_view_t,
   DT_H5E_direction_t,
   DT_H5E_type_t,
   DT_H5F_close_degree_t,
+  DT_H5F_file_space_type_t,
+  DT_H5F_fspace_strategy_t,
   DT_H5F_libver_t,
   DT_H5F_mem_t,
   DT_H5F_scope_t,
@@ -251,11 +254,18 @@ typedef enum {
   DT_H5_ih_info_t,
   DT_H5A_info_t,
   DT_H5AC_cache_config_t,
+  DT_H5AC_cache_image_config_t,
   DT_H5D_info_t,
   DT_H5E_error1_t,
   DT_H5E_error2_t,
-  DT_H5F_info_helper_t,
-  DT_H5F_info_t,
+  DT_H5F_info1_helper_t,
+  DT_H5F_info1_t,
+  DT_H5F_info2_free_t,
+  DT_H5F_info2_sohm_t,
+  DT_H5F_info2_super_t,
+  DT_H5F_info2_t,
+  DT_H5F_retry_info_t,
+  DT_H5F_sect_info_t,
   DT_H5G_info_t,
   DT_H5L_info_t,
   DT_H5ls_info_t,
@@ -300,7 +310,7 @@ hid_t create_DT_H5C_cache_incr_mode(void);
 /* typedef enum H5D_alloc_time_t { H5D_ALLOC_TIME_ERROR = -1, H5D_ALLOC_TIME_DEFAULT = 0, H5D_ALLOC_TIME_EARLY = 1, H5D_ALLOC_TIME_LATE = 2, H5D_ALLOC_TIME_INCR = 3} H5D_alloc_time_t; */
 hid_t create_DT_H5D_alloc_time_t(void);
 
-/* typedef enum H5D_chunk_index_t { H5D_CHUNK_BTREE = 0 } H5D_chunk_index_t; */
+/* typedef enum H5D_chunk_index_t { H5D_CHUNK_IDX_BTREE = 0, H5D_CHUNK_IDX_SINGLE = 1, H5D_CHUNK_IDX_NONE = 2, H5D_CHUNK_IDX_FARRAY = 3, H5D_CHUNK_IDX_EARRAY = 4, H5D_CHUNK_IDX_BT2 = 5, H5D_CHUNK_IDX_NTYPES } H5D_chunk_index_t; */
 hid_t create_DT_H5D_chunk_index_t(void);
 
 /* typedef enum H5D_fill_time_t { H5D_FILL_TIME_ERROR = -1, H5D_FILL_TIME_ALLOC = 0, H5D_FILL_TIME_NEVER = 1, H5D_FILL_TIME_IFSET = 2} H5D_fill_time_t; */
@@ -309,21 +319,24 @@ hid_t create_DT_H5D_fill_time_t(void);
 /* typedef enum H5D_fill_value_t { H5D_FILL_VALUE_ERROR =-1, H5D_FILL_VALUE_UNDEFINED =0, H5D_FILL_VALUE_DEFAULT =1, H5D_FILL_VALUE_USER_DEFINED =2} H5D_fill_value_t; */
 hid_t create_DT_H5D_fill_value_t(void);
 
-/* typedef enum H5D_layout_t { H5D_LAYOUT_ERROR = -1, H5D_COMPACT = 0, H5D_CONTIGUOUS = 1, H5D_CHUNKED = 2, H5D_NLAYOUTS = 3 } H5D_layout_t; */
+/* typedef enum H5D_layout_t { H5D_LAYOUT_ERROR = -1, H5D_COMPACT = 0, H5D_CONTIGUOUS = 1, H5D_CHUNKED = 2, H5D_VIRTUAL = 3, H5D_NLAYOUTS = 4 } H5D_layout_t; */
 hid_t create_DT_H5D_layout_t(void);
 
 /* typedef enum H5D_mpio_actual_chunk_opt_mode_t { H5D_MPIO_NO_CHUNK_OPTIMIZATION = 0, H5D_MPIO_LINK_CHUNK, H5D_MPIO_MULTI_CHUNK} H5D_mpio_actual_chunk_opt_mode_t; */
 hid_t create_DT_H5D_mpio_actual_chunk_opt_mode_t(void);
 
-/* typedef enum H5D_mpio_actual_io_mode_t { H5D_MPIO_NO_COLLECTIVE = 0x0, H5D_MPIO_CHUNK_INDEPENDENT = 0x1, H5D_MPIO_CHUNK_COLLECTIVE = 0x2, H5D_MPIO_CHUNK_MIXED = 0x1 | 0x2, H5D_MPIO_CONTIGUOUS_COLLECTIVE = 0x4} H5D_mpio_actual_io_mode_t;  */
+/* typedef enum H5D_mpio_actual_io_mode_t { H5D_MPIO_NO_COLLECTIVE = 0x0, H5D_MPIO_CHUNK_INDEPENDENT = 0x1, H5D_MPIO_CHUNK_COLLECTIVE = 0x2, H5D_MPIO_CHUNK_MIXED = 0x1 | 0x2, H5D_MPIO_CONTIGUOUS_COLLECTIVE = 0x4} H5D_mpio_actual_io_mode_t; */
 hid_t create_DT_H5D_mpio_actual_io_mode_t(void);
 
-/* typedef enum H5D_mpio_no_collective_cause_t { H5D_MPIO_COLLECTIVE = 0x00, H5D_MPIO_SET_INDEPENDENT = 0x01, H5D_MPIO_DATATYPE_CONVERSION = 0x02, H5D_MPIO_DATA_TRANSFORMS = 0x04, H5D_MPIO_MPI_OPT_TYPES_ENV_VAR_DISABLED = 0x08, H5D_MPIO_NOT_SIMPLE_OR_SCALAR_DATASPACES = 0x10, H5D_MPIO_NOT_CONTIGUOUS_OR_CHUNKED_DATASET = 0x20, H5D_MPIO_FILTERS = 0x40} H5D_mpio_no_collective_cause_t; */
+/* typedef enum H5D_mpio_no_collective_cause_t { H5D_MPIO_COLLECTIVE = 0x00, H5D_MPIO_SET_INDEPENDENT = 0x01, H5D_MPIO_DATATYPE_CONVERSION = 0x02, H5D_MPIO_DATA_TRANSFORMS = 0x04, H5D_MPIO_MPI_OPT_TYPES_ENV_VAR_DISABLED = 0x08, H5D_MPIO_NOT_SIMPLE_OR_SCALAR_DATASPACES = 0x10, H5D_MPIO_NOT_CONTIGUOUS_OR_CHUNKED_DATASET = 0x20, H5D_MPIO_PARALLEL_FILTERED_WRITES_DISABLED = 0x40, H5D_MPIO_NO_COLLECTIVE_MAX_CAUSE = 0x80} H5D_mpio_no_collective_cause_t; */
 hid_t create_DT_H5D_mpio_no_collective_cause_t(void);
 
 /* typedef enum H5D_space_status_t { H5D_SPACE_STATUS_ERROR = -1, H5D_SPACE_STATUS_NOT_ALLOCATED = 0, H5D_SPACE_STATUS_PART_ALLOCATED = 1, H5D_SPACE_STATUS_ALLOCATED = 2} H5D_space_status_t; */
 hid_t create_DT_H5D_space_status_t(void);
 
+/* typedef enum H5D_vds_view_t { H5D_VDS_ERROR = -1, H5D_VDS_FIRST_MISSING = 0, H5D_VDS_LAST_AVAILABLE = 1} H5D_vds_view_t; */
+hid_t create_DT_H5D_vds_view_t(void);
+
 /* typedef enum H5E_direction_t { H5E_WALK_UPWARD = 0, H5E_WALK_DOWNWARD = 1 } H5E_direction_t; */
 hid_t create_DT_H5E_direction_t(void);
 
@@ -333,7 +346,13 @@ hid_t create_DT_H5E_type_t(void);
 /* typedef enum H5F_close_degree_t { H5F_CLOSE_DEFAULT = 0, H5F_CLOSE_WEAK = 1, H5F_CLOSE_SEMI = 2, H5F_CLOSE_STRONG = 3} H5F_close_degree_t; */
 hid_t create_DT_H5F_close_degree_t(void);
 
-/* typedef enum H5F_libver_t { H5F_LIBVER_EARLIEST, H5F_LIBVER_LATEST } H5F_libver_t; */
+/* typedef enum H5F_file_space_type_t { H5F_FILE_SPACE_DEFAULT = 0, H5F_FILE_SPACE_ALL_PERSIST = 1, H5F_FILE_SPACE_ALL = 2, H5F_FILE_SPACE_AGGR_VFD = 3, H5F_FILE_SPACE_VFD = 4, H5F_FILE_SPACE_NTYPES } H5F_file_space_type_t; */
+hid_t create_DT_H5F_file_space_type_t(void);
+
+/* typedef enum H5F_fspace_strategy_t { H5F_FSPACE_STRATEGY_FSM_AGGR = 0, H5F_FSPACE_STRATEGY_PAGE = 1, H5F_FSPACE_STRATEGY_AGGR = 2, H5F_FSPACE_STRATEGY_NONE = 3, H5F_FSPACE_STRATEGY_NTYPES } H5F_fspace_strategy_t; */
+hid_t create_DT_H5F_fspace_strategy_t(void);
+
+/* typedef enum H5F_libver_t { H5F_LIBVER_ERROR = -1, H5F_LIBVER_EARLIEST = 0, H5F_LIBVER_V18 = 1, H5F_LIBVER_V110 = 2, H5F_LIBVER_NBOUNDS} H5F_libver_t; */
 hid_t create_DT_H5F_libver_t(void);
 
 /* typedef enum H5F_mem_t { H5FD_MEM_NOLIST = -1, H5FD_MEM_DEFAULT = 0, H5FD_MEM_SUPER = 1, H5FD_MEM_BTREE = 2, H5FD_MEM_DRAW = 3, H5FD_MEM_GHEAP = 4, H5FD_MEM_LHEAP = 5, H5FD_MEM_OHDR = 6, H5FD_MEM_NTYPES } H5F_mem_t; */
@@ -369,7 +388,7 @@ hid_t create_DT_H5O_type_t(void);
 /* typedef enum H5PL_type_t { H5PL_TYPE_ERROR = -1, H5PL_TYPE_FILTER = 0, H5PL_TYPE_NONE = 1 } H5PL_type_t; */
 hid_t create_DT_H5PL_type_t(void);
 
-/* typedef enum { H5R_BADTYPE = (-1), H5R_OBJECT, H5R_DATASET_REGION, H5R_MAXTYPE } H5R_type_t; */
+/* typedef enum H5R_type_t { H5R_BADTYPE = (-1), H5R_OBJECT, H5R_DATASET_REGION, H5R_MAXTYPE } H5R_type_t; */
 hid_t create_DT_H5R_type_t(void);
 
 /* typedef enum H5S_class_t { H5S_NO_CLASS = -1, H5S_SCALAR = 0, H5S_SIMPLE = 1, H5S_NULL = 2 } H5S_class_t; */
@@ -441,9 +460,12 @@ hid_t create_DT_H5_ih_info_t(void);
 /* typedef struct { hbool_t corder_valid; H5O_msg_crt_idx_t corder; H5T_cset_t cset; hsize_t data_size} H5A_info_t; */
 hid_t create_DT_H5A_info_t(void);
 
-/* typedef struct H5AC_cache_config_t{ int version; hbool_t rpt_fcn_enabled; hbool_t open_trace_file; hbool_t close_trace_file; char trace_file_name[H5AC__MAX_TRACE_FILE_NAME_LEN + 1]; hbool_t evictions_enabled; hbool_t set_initial_size; size_t initial_size; double min_clean_fraction; size_t max_size; size_t min_size; long int epoch_length; enum H5C_cache_incr_mode incr_mode; double lower_hr_threshold; double increment; hbool_t apply_max_increment; size_t max_increment; enum H5C_cache_flash_incr_mode flash_incr_mode; double flash_multiple; double flash_threshold; enum H5C_cache_decr_mode decr_mode; double upper_hr_threshold; double decrement; hbool_t apply_max_decrement; size_t max_decrement; int epochs_before_eviction; hbool_t apply_empty_reserve; double empty_reserve; int dirty_bytes_threshold; int metadata_write_strategy} H5AC_cache_config_t; */
+/* typedef struct H5AC_cache_config_t{ int version; hbool_t rpt_fcn_enabled; hbool_t open_trace_file; hbool_t close_trace_file; char trace_file_name[H5AC__MAX_TRACE_FILE_NAME_LEN + 1]; hbool_t evictions_enabled; hbool_t set_initial_size; size_t initial_size; double min_clean_fraction; size_t max_size; size_t min_size; long int epoch_length; enum H5C_cache_incr_mode incr_mode; double lower_hr_threshold; double increment; hbool_t apply_max_increment; size_t max_increment; enum H5C_cache_flash_incr_mode flash_incr_mode; double flash_multiple; double flash_threshold; enum H5C_cache_decr_mode decr_mode; double upper_hr_threshold; double decrement; hbool_t apply_max_decrement; size_t max_decrement; int epochs_before_eviction; hbool_t apply_empty_reserve; double empty_reserve; size_t dirty_bytes_threshold; int metadata_write_strategy} H5AC_cache_config_t; */
 hid_t create_DT_H5AC_cache_config_t(void);
 
+/* typedef struct H5AC_cache_image_config_t { int version; hbool_t generate_image; hbool_t save_resize_status; int entry_ageout} H5AC_cache_image_config_t; */
+hid_t create_DT_H5AC_cache_image_config_t(void);
+
 /* typedef struct H5D_info_t { int rank; char* dims; char* maxdims; H5T_class_t type_class; H5S_class_t space_class} H5D_info_t; */
 hid_t create_DT_H5D_info_t(void);
 
@@ -453,11 +475,29 @@ hid_t create_DT_H5E_error1_t(void);
 /* typedef struct H5E_error2_t { hid_t cls_id; hid_t maj_num; hid_t min_num; unsigned line; const char *func_name; const char *file_name; const char *desc} H5E_error2_t; */
 hid_t create_DT_H5E_error2_t(void);
 
-/* typedef struct H5F_info_helper_t { hsize_t hdr_size; H5_ih_info_t msgs_info} H5F_info_helper_t;  */
-hid_t create_DT_H5F_info_helper_t(void);
+/* typedef struct H5F_info1_helper_t { hsize_t hdr_size; H5_ih_info_t msgs_info} H5F_info1_helper_t;  */
+hid_t create_DT_H5F_info1_helper_t(void);
 
-/* typedef struct H5F_info_t { hsize_t super_ext_size; H5F_info_helper_t sohm} H5F_info_t; */
-hid_t create_DT_H5F_info_t(void);
+/* typedef struct H5F_info1_t { hsize_t super_ext_size; H5F_info1_helper_t sohm} H5F_info1_t; */
+hid_t create_DT_H5F_info1_t(void);
+
+/* typedef struct H5F_info2_free_t { unsigned version; hsize_t meta_size; hsize_t tot_space} H5F_info2_free_t; */
+hid_t create_DT_H5F_info2_free_t(void);
+
+/* typedef struct H5F_info2_sohm_t { unsigned version; hsize_t hdr_size; H5_ih_info_t msgs_info} H5F_info2_sohm_t; */
+hid_t create_DT_H5F_info2_sohm_t(void);
+
+/* typedef struct H5F_info2_super_t { unsigned version; hsize_t super_size; hsize_t super_ext_size} H5F_info2_super_t; */
+hid_t create_DT_H5F_info2_super_t(void);
+
+/* typedef struct H5F_info2_t { H5F_info2_super_t super; H5F_info2_free_t free; H5F_info2_sohm_t sohm} H5F_info2_t; */
+hid_t create_DT_H5F_info2_t(void);
+
+/* typedef struct H5F_retry_info_t { unsigned nbins; uint32_t *retries[H5F_NUM_METADATA_READ_RETRY_TYPES]} H5F_retry_info_t; */
+hid_t create_DT_H5F_retry_info_t(void);
+
+/* typedef struct H5F_sect_info_t { haddr_t addr; hsize_t size} H5F_sect_info_t; */
+hid_t create_DT_H5F_sect_info_t(void);
 
 /* typedef struct H5G_info_t { H5G_storage_type_t storage_type; hsize_t nlinks; int64_t max_corder; hbool_t mounted} H5G_info_t; */
 hid_t create_DT_H5G_info_t(void);
